MSELoss
=======

.. currentmodule:: pykeen.losses

.. autoclass:: MSELoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MSELoss.synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: synonyms
